#
# spec file for package libime
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libime
Version:        1.1.10
Release:        1.3
Summary:        Generic input method implementation
License:        LGPL-2.1-or-later
Group:          System/I18n/Chinese
URL:            https://github.com/fcitx/libime
Source:         https://download.fcitx-im.org/fcitx5/%{name}/%{name}-%{version}_dict.tar.zst
#PATCH-FIX-UPSTREAM boost 1.66 in leap 15.5 doesn't have container_hash/hash.hpp, it was splitted
# from functional/hash.hpp since boost 1.67
Patch:          %{name}-1.1.10-boost166.patch
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules
BuildRequires:  fcitx5-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_iostreams-devel
BuildRequires:  libboost_regex-devel
BuildRequires:  libzstd-devel
BuildRequires:  zstd

%description
This is a library to support generic input method implementation.

%package devel
Summary:        Development files for libime
Group:          Development/Libraries/C and C++
Requires:       libIMECore0 = %{version}
Requires:       libIMEPinyin0 = %{version}
Requires:       libIMETable0 = %{version}

%description devel
This package provides development files for libime.

%package tools
Summary:        Toolkit for libime
Group:          System/I18n/Chinese

%description tools
This package provides toolkit for libime.

%package -n libIMECore0
Summary:        Core library for libime
Group:          System/Libraries
Requires:       libime-tools

%description -n libIMECore0
This package provides core library for libime.

%package -n libIMEPinyin0
Summary:        Pinyin library for libime
Group:          System/Libraries
Requires:       libime-dicts

%description -n libIMEPinyin0
This package provides pinyin library for libime.

%package -n libIMETable0
Summary:        Table library for libime
Group:          System/Libraries
Requires:       libime-dicts

%description -n libIMETable0
This package provides table library for libime.

%package dicts
Summary:        Dictionary files for libime
Group:          System/I18n/Chinese

%description dicts
This package provides dictionary files for libime.

%prep
%autosetup -p1

%build
export LANG=en_US.UTF-8
%cmake -DCMAKE_SKIP_RPATH=OFF
%make_build

%install
%cmake_install
%fdupes %{buildroot}

%post -n libIMECore0 -p /sbin/ldconfig
%post -n libIMEPinyin0 -p /sbin/ldconfig
%post -n libIMETable0 -p /sbin/ldconfig
%postun -n libIMECore0 -p /sbin/ldconfig
%postun -n libIMEPinyin0 -p /sbin/ldconfig
%postun -n libIMETable0 -p /sbin/ldconfig

%files tools
%{_bindir}/libime_history
%{_bindir}/libime_prediction
%{_bindir}/libime_slm_build_binary
%{_bindir}/libime_migrate_fcitx4_pinyin
%{_bindir}/libime_migrate_fcitx4_table
%{_bindir}/libime_pinyindict
%{_bindir}/libime_tabledict

%files -n libIMECore0
%{_libdir}/libIMECore.so.0
%{_libdir}/libIMECore.so.%{version}
%{_libdir}/libime

%files -n libIMEPinyin0
%{_libdir}/libIMEPinyin.so.0
%{_libdir}/libIMEPinyin.so.%{version}

%files -n libIMETable0
%{_libdir}/libIMETable.so.0
%{_libdir}/libIMETable.so.%{version}

%files devel
%license LICENSES
%doc README.md
%{_includedir}/LibIME
%{_libdir}/cmake/LibIME*
%{_libdir}/libIMECore.so
%{_libdir}/libIMEPinyin.so
%{_libdir}/libIMETable.so

%files dicts
%{_datadir}/libime

%changelog
* Wed Jan 29 2025 Marguerite Su <i@marguerite.su>
- update to 1.1.10
  * New language model to fix some frequency issue
  * Correction support for shuangpin
  * Improving segmentation algorithm for pinyin
- refresh libime-1.1.10-boost166.patch
- drop libime-1.1.9-boost166.patch
* Sun Jan  5 2025 Marguerite Su <i@marguerite.su>
- update to 1.1.9:
  * update model and dict
  * Manually adjust certain character weight in dict
    to avoid some meaningless score
- add patch libime-1.1.9-boost166.patch
  * <boost/container_hash/hash.hpp> was splitted from
    <boost/functional/hash.hpp> since boost 1.67
* Sun Sep  8 2024 Dirk Müller <dmueller@suse.com>
- update to 1.1.8:
  * When parsing with correction flag, u,i,v should not be
    considered as invalid
  * Fix possible prediction duplicate
  * Refactor pinyin map generatation with meaningful enum
  * Allow un -> vn for jqxy
* Wed May 22 2024 Marguerite Su <i@marguerite.su>
- update to 1.1.7:
  * Support more pinyin correction
  * Improve candidates to cursor logic
  * Remove shuang pin's ng -> mapping to pinyin ng
* Sun Mar 17 2024 Dirk Müller <dmueller@suse.com>
- update to 1.1.6:
  * Fix TscanCode detections
  * clang tidy and coverity clean ups
  * Handle customized single char final mapping
* Sun Feb  4 2024 Marguerite Su <i@marguerite.su>
- update to 1.1.5
  * Replace PUA character with non-PUA unicode in the table data.
- changes in 1.1.4
  * Improve Pinyin prediction order
  * Fix two shuangpin profile bugs
  * Fix build on musl
  * Fix for exact match mode
  * libime_tabledict adds a new mode flag for extra dict.
- changes in 1.1.3
  * reduce user model weight and unigram weight.
  * new pinyin prediction API to allow prediction from dictionaries.
  * Add more pinyin correction for wrong order e.g. (hzi -> zhi)
  * Fix exact match mode in table.
* Tue Oct  3 2023 Marguerite Su <i@marguerite.su>
- update to 1.1.2
  * Allow table to include words without code
  * allow table ordering ignore the code length
  * Allow value to be quoted
  * Apply ZSTD compression the pinyin/table dict and user history.
  * fix some performance issue for certain pinyin input
  * Allow table rule to specify character from backwards.
* Sun Aug 27 2023 Marguerite Su <i@marguerite.su>
- update to 1.1.1
  * hotfix for user pinyin parsing
* Sun Aug 20 2023 Marguerite Su <i@marguerite.su>
- update to 1.1.0
  * new language model
  * fix full pinyin shuangpin preedit to use the pinyin of first candidate
  * fuzzy pinyin now allows jqxy with van
  * libime_pinyindict now skips invalid lines when building dictionary file
  * improve partial match flag for chaizi
* Thu Apr 27 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.17:
  * Accept lue or nue when parsing text formatted dictionary
  * Don't make partial sp like z/c/s match zh/ch/sh
  * Set a search size hard limit on the nbest search
  * use int64_t for scoped clock
* Thu Dec  8 2022 Dirk Müller <dmueller@suse.com>
- update to 1.0.16:
  * Use our own hasher for std::string because boost stream may not
    use a fixed implementation for string hash
* Sun Nov 20 2022 Fusion Future <qydwhotmail@gmail.com>
- Update to 1.0.15
  * Update translation
* Tue Sep 20 2022 Marguerite Su <i@marguerite.su>
- update version 1.0.14
  * Update language model data and dictionary
  * Add support for libime_history to compile text to binary data
- drop libime-1.0.13-return-0.0-for-other-platforms-in-usage.patch,
  upstreamed
* Mon Jul 25 2022 Takashi Iwai <tiwai@suse.com>
- Remove yet another stale file, table.tar.gz
* Sun Jul 24 2022 Fusion Future <qydwhotmail@gmail.com>
- Remove one unused file
  * libime-1.0.13.tar.xz
* Tue Jul  5 2022 Fusion Future <qydwhotmail@gmail.com>
- Update to 1.0.13
  * fix a crash in pinyin under certain rare cases
- Use _dict tar which contains all the needed dictionaries
- Fix build by adding return statement (gh#kpu/kenlm#391)
  * libime-1.0.13-return-0.0-for-other-platforms-in-usage.patch
- Remove unneeded patch
  * libime-no-download.patch
* Tue Jan 25 2022 Marguerite Su <i@marguerite.su>
- update version 1.0.11
  * Partial shuangpin support. It's a new option
* Wed Dec 15 2021 Marguerite Su <i@marguerite.su>
- update version 1.0.10
  * Add API for dict manage
- changes in 1.0.9
  * Allow pinyinjiajia shuangpin to use xiao'he style leading.
* Sat Oct  2 2021 Fusion Future <qydwhotmail@gmail.com>
- Update to 1.0.8
  * Fix build with libboost 1.77 (boo#1191228).
  * Add j|q|x|y ve as fuzzy for ue and add inner segment for ue fuzzy.
- Drop upstreamed patch
  * libime-1.0.7-boost-1.66.patch
* Wed May  5 2021 Marguerite Su <i@marguerite.su>
- update version 1.0.7
  * Improve result for in complete pinyin. In the old implementation some
    "better" suggestions are filtered due to size limit and performance.
- changes in version 1.0.6
  * minor fix in pinyin pronunciation weight. When adding new missing
    pronunciation in the last release, the weight was not assigned
    to some common characters, thus it causes confusion in the order.
    This release update with weight for common characters and should
    restore the ordering for those characters (e.g. 她 射)
- changes in version 1.0.5
  * Update character data and add pronunciations.
- add patch libime-1.0.7-boost-1.66.patch
* Tue Mar 16 2021 Marguerite Su <i@marguerite.su>
- update version 1.0.4
  * Add a lot of new pronunciation to the data
* Sat Jan 30 2021 Marguerite Su <i@marguerite.su>
- update version 1.0.3
* Sun Dec  6 2020 Marguerite Su <i@marguerite.su>
- update version 1.0.2
* Tue Nov 10 2020 Marguerite Su <i@marguerite.su>
- update version 1.0.1
* Thu Sep  3 2020 Marguerite Su <i@marguerite.su>
- update version 0.0.1+git20200901.e05fdd3
- update kenlm-96d393c.tar.xz to kenlm-20200829.01c49fe.tar.xz
* Tue Mar  3 2020 Xu Zhao <i@xuzhao.net>
- update version 0.0.1+git20191230.5b6e890
- add new dependency: kenlm-96d393c.tar.xz
* Sun Sep 22 2019 Marguerite Su <i@marguerite.su>
- update version 0.0.0+git20180826.3254159
  * Protect against duplicate imported targets.
* Sun Aug 26 2018 i@marguerite.su
- initial package
